(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.sign_widget = {
    attach: function (context) {
      $(".signature-pad", context).once("initiate-signature-pad").each(function () {
        function resizeCanvas(canvas) {
          let ratio = Math.max(window.devicePixelRatio || 1, 1);
          canvas.width = canvas.offsetWidth * ratio;
          canvas.height = canvas.offsetHeight * ratio;
          canvas.getContext("2d").scale(ratio, ratio);
        }
        $("canvas.signature-pad").each(function (index) {
          let setting_pad = $(this).data();
          let index_pad = $(this).attr('id');
          let canvas = document.getElementById(index_pad);
          let background = '';
          // Assign the hidden field (that saves the signature) to a variable.
          background = $(this).closest('.signature')
            .width($(this).width())
            .height($(this).height())
            .find(".background");
          // Instantiate the signaturepad itself.
          setting_pad.onEnd = function () {
            // When a signature is done being signed, set the hidden field to contain the data.
            $('#' + index_pad + '-sign').val(window[index_pad].toDataURL('image/png'));
          };
          window[index_pad] = new SignaturePad(canvas, setting_pad);
          if (background && background.attr('src')) {
            window[index_pad].fromDataURL(background.attr('src'));
          }
          window.addEventListener("resize", function () {
            resizeCanvas(canvas);
          });
        });
        // Toolbox buttons clear.
        $('.signature_panel .clear').on('click', function () {
          let index_pad = $(this).data('id');
          window[index_pad].clear();
          $(this).closest('.esign_container').find(".signature-storage").val('');
        });
        // Fomatter buttons save.
        $('.signature_panel .save').on('click', function () {
          const index_pad = $(this).data('id');
          let data = $(this).closest('.esign_container').find(".signature-storage").data();
          if(data === undefined) {
            return;
          }
          data.sign = $(this).closest('.esign_container').find(".signature-storage").val();
          $(this).parent().remove();
          $.ajax({
            url: Drupal.url('ajax/sign_widget/sendSign/' + index_pad),
            type: 'POST',
            cache: false,
            contentType: "application/x-www-form-urlencoded;charset=UTF-8",
            data: data,
            success: function (data) {
              $('#' + data[0].selector + '-sign').closest('.esign_container').parent().html(
                $('<img>',{src:data[0].sign_src})
              );
            }
          });

        });
        //Show toolbox to change color.
        $('.signature_panel .toolbox input').on('change', function () {
          let index_pad = $(this).data('id');
          let type = $(this).data('type');
          window[index_pad][type] = $(this).val();
          $('#' + index_pad).data(type, $(this).val());
          if (type == 'dotSize') {
            window[index_pad].maxWidth = $(this).val();
            $('#' + index_pad).data('maxWidth', $(this).val());
          }
        });
      });

      Drupal.AjaxCommands.prototype.sendSign = function (ajax, response, status) {
        $('#' + index_pad)
          .find('input[type="hidden"]')
          .trigger('sendSign');

        console.log('trigger cmd',data);
      };
    }
  };
}(jQuery, Drupal));
